%define soname	claw
%define major	1
%define libname	%mklibname %{soname} %{major}
%define devname	%mklibname %{soname} -d

Name:		libclaw
Version:	1.7.4
Release:	%mkrel 10
Summary:	C++ Library of various utility functions
Group:		System/Libraries
License:	LGPLv2
URL:		http://libclaw.sourceforge.net/
Source0:	https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Patch0:		libclaw-1.6.1-nostrip.patch
Patch1:		libclaw-1.7.4-libdir.patch
Patch2:		libclaw-1.7.4-git-declare-static-libs-as-static.diff
Patch3:		libclaw-1.7.4-gcc7.patch
Patch4:		libclaw-1.7.4-gcc62.patch

BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	gettext-devel
BuildRequires:	boost-devel

%description
CLAW is a C++ Library providing various tools in different domains,
like a Tweener framework, Bézier curves manipulation, a map with multiple
value types, a binary search tree container implemented as an AVL and
an implementation of the sockets as std::stream.

The library also includes a set of classes to easily load and write png,
jpeg, gif files and other image formats.

Finally, a part of the library is devoted to artificial intelligence
in games and includes a generic alpha-beta algorithm.

#----------------------------------------------------------------------------

%package -n	%{libname}
Summary:	C++ Library of various utility functions
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}
Obsoletes:	%{name} < 1.7.4-2

%description -n	%{libname}
CLAW is a C++ Library providing various tools in different domains,
like a Tweener framework, Bézier curves manipulation, a map with multiple
value types, a binary search tree container implemented as an AVL and
an implementation of the sockets as std::stream.

The library also includes a set of classes to easily load and write png,
jpeg, gif files and other image formats.

Finally, a part of the library is devoted to artificial intelligence
in games and includes a generic alpha-beta algorithm.

%files -n	%{libname} -f %{name}.lang
%doc ChangeLog
%{_libdir}/*.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n	%{devname}
Summary:	Development files for Claw library
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 1.7.4-2

%description -n	%{devname}
This package contains files needed to develop and build software against
CLAW (C++ Library Absolutely Wonderful).

%files -n	%{devname}
%{_bindir}/claw-config
%{_datadir}/cmake/%{name}
%dir %{_datadir}/%{name}
%{_includedir}/claw
%{_libdir}/*.so

#----------------------------------------------------------------------------

%package	doc
Summary:	Documentation for Claw library
Group:		Development/C++
BuildArch:	noarch
Recommends:	%{libname} = %{version}-%{release}

%description	doc
This package contains the documentation files for the CLAW (C++ Library
Absolutely Wonderful) library.

%files		doc
%doc %{_docdir}/%{name}%{major}

#----------------------------------------------------------------------------

%package	examples
Summary:	Example files for Claw library
Group:		Development/C++
BuildArch:	noarch
Recommends:	%{devname} = %{version}-%{release}

%description	examples
This package contains the example files for the CLAW (C++ Library
Absolutely Wonderful) library.

%files		examples
%{_datadir}/%{name}/examples

#----------------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake
%cmake_build

find examples/{curve,graph,game_ai/morpion_console,avl} -type f |
while read F
do
	iconv -f iso8859-1 -t utf-8 $F |sed 's/\r//' >.utf8
	touch -r $F .utf8
	mv .utf8 $F
done

%install
%cmake_install

%find_lang %{name}

# Install examples to %%_datadir
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -r examples %{buildroot}%{_datadir}/%{name}/

# Remove static libraries
find %{buildroot}%{_libdir} -name "*.a" -delete


%changelog
* Fri Mar 18 2022 umeabot <umeabot> 1.7.4-10.mga9
+ Revision: 1798413
- Mageia 9 Mass Rebuild

* Thu Feb 13 2020 daviddavid <daviddavid> 1.7.4-9.mga8
+ Revision: 1513978
- use new cmake macros
- fix library description
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 1.7.4-8.mga7
+ Revision: 1298788
- Mageia 7 Mass Rebuild

* Sun Sep 24 2017 cjw <cjw> 1.7.4-7.mga7
+ Revision: 1158387
- add 2 patches from fedora to fix build with gcc 7

* Thu Feb 11 2016 umeabot <umeabot> 1.7.4-6.mga6
+ Revision: 955451
- Mageia 6 Mass Rebuild

* Fri Aug 28 2015 cjw <cjw> 1.7.4-5.mga6
+ Revision: 870369
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 1.7.4-4.mga5
+ Revision: 740701
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.7.4-3.mga5
+ Revision: 681382
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Jun 12 2014 akien <akien> 1.7.4-2.mga5
+ Revision: 635899
- Improve description
- Use proper package names for shared library and dev library
- Drop static libraries
- Fix packaging issue with all libraries being put in the main lib package

* Tue Nov 12 2013 juancho <juancho> 1.7.4-1.mga4
+ Revision: 550810
- Imported from Fedora package


* Sun Aug 18 2013 Lubomir Rintel <lkundrak@v3.sk> - 1.7.4-1
- Rebase
- Fix FTBFS

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 1.7.0-9
- Rebuild for boost 1.54.0

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Dec 21 2012 Adam Tkac <atkac redhat com> - 1.7.0-7
- rebuild against new libjpeg

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-5
- Rebuilt for c++ ABI breakage

* Sun Feb  5 2012 Tom Callaway <spot@fedoraproject.org> - 1.7.0-4
- fix png.hpp to include zlib.h

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 06 2011 Adam Jackson <ajax@redhat.com> - 1.7.0-2
- Rebuild for new libpng

* Thu Aug 25 2011 Tom Callaway <spot@fedoraproject.org> - 1.7.0-1
- update to 1.7.0

* Mon Apr 18 2011 Tom Callaway <spot@fedoraproject.org> - 1.6.1-1
- update to 1.6.1

* Fri Feb 11 2011 Lubomir Rintel <lkundrak@v3.sk> - 1.5.4-7
- Fix Rawhide build

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 29 2010 jkeating - 1.5.4-5
- Rebuilt for gcc bug 634757

* Sat Sep 18 2010 Tom "spot" Callaway <tcallawa@redhat.com> - 1.5.4-4
- Fix wrong return type of 'claw::log_system::operator<<'
- Fix incorrect return type in basic_socket.

* Fri Oct 23 2009 Lubomir Rintel <lkundrak@v3.sk> - 1.5.4-3
- Really fix the examples encoding

* Fri Oct 02 2009 Lubomir Rintel <lkundrak@v3.sk> - 1.5.4-2
- Merge in changes from Xavier Bachelot's package:
- More sensible Group name
- Fix libdir name for 64bit archs
- Add examples to documentation
- Fix examples encoding
- Let -devel require cmake

* Fri Sep 18 2009 Lubomir Rintel <lkundrak@v3.sk> - 1.5.4-1
- Initial packaging
